==> dl.php?src=linea21_2_5_0.zip: linea21/page/help.php <==
<?php
/**
 * Page module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\page
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>
<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','add');?></p>
<ul>
	<li><?php echo _t('page','help_add1');?></li>
	<li><?php echo _t('page','help_add2');?></li>
	<li><?php echo _t('page','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
  ?>
    <p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','det');?></p>
    <ul>
    	<li><?php echo _t('page','help_det1');?></li>
    	<li><?php echo _t('page','help_det2');?></li>
    </ul>
  <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','mod');?></p>
<ul>
	<li><?php echo _t('page','help_mod1');?></li>
	<li><?php echo _t('page','help_mod2');?></li>
	<li><?php echo _t('page','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','list');?></p>
<ul>
	<li><?php echo _t('page','help_list1');?></li>
	<li><?php echo _t('page','help_list2');?></li>
	<li><?php echo _t('page','help_list3');?></li>
	<li><?php echo _t('page','help_list4');?></li>
	<li><?php echo _t('page','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'sup') {
        ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','sup');?></p>
<ul>
	<li><?php echo _t('page','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->

==> dl.php?src=linea21_2_7_0.zip: linea21/page/help.php <==
<?php
/**
 * Page module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\page
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="fa fa-life-ring" aria-hidden="true"></i> <?php echo _t('help','title');?></a>
<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','add');?></p>
<ul>
	<li><?php echo _t('page','help_add1');?></li>
	<li><?php echo _t('page','help_add2');?></li>
	<li><?php echo _t('page','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
  ?>
    <p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','det');?></p>
    <ul>
    	<li><?php echo _t('page','help_det1');?></li>
    	<li><?php echo _t('page','help_det2');?></li>
    </ul>
  <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','mod');?></p>
<ul>
	<li><?php echo _t('page','help_mod1');?></li>
	<li><?php echo _t('page','help_mod2');?></li>
	<li><?php echo _t('page','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','list');?></p>
<ul>
	<li><?php echo _t('page','help_list1');?></li>
	<li><?php echo _t('page','help_list2');?></li>
	<li><?php echo _t('page','help_list3');?></li>
	<li><?php echo _t('page','help_list4');?></li>
	<li><?php echo _t('page','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'sup') {
        ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('page','sup');?></p>
<ul>
	<li><?php echo _t('page','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
